@@ -263,9 +263,9 @@ def rz2brzt(eqm, r_in, z_in, t_in=None):
         interpBz[jt] = f_bz(r, z, grid=False)
         interpBt[jt] = f_bt(r, z, grid=False)
 
-    return interpBr/(eqm.psi_fac*dz), \
-           interpBz/(eqm.psi_fac*dr), \
-           interpBt/np.abs(eqm.psi_fac) * eqm.phi_sign
+    return interpBr/(-abs(eqm.psi_fac)*dz), \
+           interpBz/(-abs(eqm.psi_fac)*dr), \
+           interpBt/eqm.psi_fac * eqm.phi_sign
 
 
 def Bmesh(eqm, t_in=None):
@@ -317,9 +317,9 @@ def Bmesh(eqm, t_in=None):
         fBt = interp1d(eqm.pfl[i], eqm.jpol[i], kind='linear', fill_value='extrapolate')
         Bt[jt] = fBt(Psi)*mu_0/eqm.Rmesh[:, None]
 
-    return Br/(eqm.psi_fac*dz), \
-           Bz/(eqm.psi_fac*dr), \
-           Bt/np.abs(eqm.psi_fac) * eqm.phi_sign
+    return Br/(-abs(eqm.psi_fac)*dz), \
+           Bz/(-abs(eqm.psi_fac)*dr), \
+           Bt/eqm.psi_fac * eqm.phi_sign
 
 
 def rz2rho(eqm, r_in, z_in, t_in=None, coord_out='rho_pol', extrapolate=True):
