@@ -61,7 +61,7 @@ class EQU:
             ## Time grid of equilibrium shotfile
             self.time = self.sf.getobject('time')
             nt = len(self.time)
-            parmv = self.sf.getparset('PARMV')
+            parmv = self.sf.sfh['PARMV'].pars
             nR = parmv['M'] + 1
             nZ = parmv['N'] + 1
             ## R of PFM cartesian grid [m]
