@@ -17,5 +17,5 @@ class SFOBJ(np.ndarray):
     def __array_finalize__(self, obj):
 
         if obj is None: return
-        for attr in ('objnam', 'obj_type', 'level', 'status', 'object_type', 'errcode', 'rel', 'address', 'length', 'descr', 'data_format', 'phys_unit', 'stat_ext'):
+        for attr in ('objnam', 'obj_type', 'object_type', 'level', 'status', 'errcode', 'rel', 'relations', 'address', 'length', 'descr', 'data_format', 'physunit', 'phys_unit', 'stat_ext', 'n_pre', 'n_steps', 'tbase_type'):
             self.__dict__[attr] = getattr(obj, attr, None)
