@@ -2,7 +2,7 @@ import os, datetime, logging
 from struct import unpack
 import numpy as np
 
-from aug_sfutils import sfdics, sfh_rw, sfobj, manage_ed, parse_kwargs, str_byt, libddc, getlastshot
+from aug_sfutils import sfdics, sfhread, sfobj, manage_ed, parse_kwargs, str_byt, libddc, getlastshot
 
 PPGCLOCK = [1e-6, 1e-5, 1e-4, 1e-3]
 
@@ -80,7 +80,7 @@ def getgc(nshot=30136):
                 comp_d[lbl] = type('', (), {})()
                 comp_d[lbl].r = rrgc[inxbeg[jcom]: inxbeg[jcom+1]]
                 comp_d[lbl].z = zzgc[inxbeg[jcom]: inxbeg[jcom+1]]
-    
+
     return comp_d
 
 
@@ -156,7 +156,7 @@ class SFREAD:
                 if len(byt_str) < 128:
                     logger.error('Error: shotfile %s has < 128 bytes, ignored' %(self.sfile))
                     return
-                self.sfh = sfh_rw.read_sfh(byt_str)
+                self.sfh = sfhread.read_sfh(byt_str)
                 self.status = True
         else:
             logger.error('Shotfile %s not found' %self.sfile)
@@ -170,6 +170,14 @@ class SFREAD:
             for obj in self.sfh.keys():
                 if hasattr(self.sfh[obj], 'address'):
                     self.sfh[obj].address *= size_fac
+
+        for parset in self.parsets:
+            logger.debug('ParSet %s', parset)
+            try:
+                self.sfh[parset].pars = self.getparset(parset)
+            except:
+                self.sfh[parset].pars = None
+
         self.cache = {}
 
 
@@ -177,12 +185,14 @@ class SFREAD:
 
         if not self.status:
             return None
+
+        if name in self.parsets:
+            return self.sfh[name].pars
+
         if name not in self.cache.keys():
             if name in self.objects:
                 self.cache[name] = self.getobject(name)
-            elif name in self.parsets:
-                self.cache[name] = self.getparset(name)
-            else:
+            elif name not in self.parsets:
                 logger.error('Signal %s:%s not found for shot #%d', self.diag, name, self.shot)
                 return None
         return self.cache[name]
@@ -270,7 +280,9 @@ class SFREAD:
                 logger.warning('%s has no Timebase associated, returning full array', obj)
                 return self.getobject(obj)
             jt_beg, jt_end = tb.searchsorted((tbeg, tend))
-            if otyp in (Signal, TimeBase, AreaBase) or self.time_last(obj):
+            if otyp == TimeBase:
+                return tb[jt_beg: jt_end]
+            elif otyp in (Signal, AreaBase) or self.time_last(obj):
                 return self.getobject(obj, nbeg=jt_beg, nend=jt_end)
             elif self.time_first(obj):
                 return self.getobject(obj)[jt_beg: jt_end]
@@ -439,13 +451,13 @@ class SFREAD:
                 caltyp = self.sfh[rel].cal_type
                 if caltyp == LinCalib:
                     logger.info('PSet for calib: %s' %rel)
-                    return self.getparset(rel)
+                    return self.sfh[rel].pars
                 elif caltyp == extCalib:
-                    diag_ext = self.getparset(rel)['DIAGNAME']
+                    diag_ext = self.sfh[rel].pars['DIAGNAME']
                     diag_ext = ''.join([str_byt.to_str(x) for x in diag_ext])
                     shot_ext = libddc.previousshot(diag_ext, shot=self.shot)
                     ext = read_other_sf(shot_ext, diag_ext)
-                    return ext.getparset(rel) # same name in external shotfile
+                    return ext.sfh[rel].pars # same name in external shotfile
         return None
 
 
@@ -557,7 +569,7 @@ class SFREAD:
         Returns a DEVICE object
         """
 
-        return self.getparset(lbl)
+        return self.sfh[lbl].pars
 
 
     def get_ts06(self):
@@ -565,7 +577,7 @@ class SFREAD:
         ts06 = None
         for obj in self.parsets:
             if self.sfh[obj].obj_type == Device:
-                ps = self.getparset(obj)
+                ps = self.sfh[obj].pars
                 if 'TS06' in ps.keys():
                     ts6 = ps['TS06']
                     if ts6 > 1e15:
@@ -593,7 +605,7 @@ class SFREAD:
 
         for rel_obj in self.sfh[obj2].relations:
             if self.sfh[rel_obj].obj_type == Device: # related device
-                ps = self.getparset(rel_obj)
+                ps = self.sfh[rel_obj].pars
                 if 'TS06' in ps.keys():
                     ts6 = ps['TS06']
                     if ts6 > 1e15:
